(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    (global = global || self, global.InlineInput = factory());
}(this, (function () { 'use strict';

    function noop() { }
    function assign(tar, src) {
        // @ts-ignore
        for (const k in src)
            tar[k] = src[k];
        return tar;
    }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function create_slot(definition, ctx, $$scope, fn) {
        if (definition) {
            const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
            return definition[0](slot_ctx);
        }
    }
    function get_slot_context(definition, ctx, $$scope, fn) {
        return definition[1] && fn
            ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
            : $$scope.ctx;
    }
    function get_slot_changes(definition, $$scope, dirty, fn) {
        if (definition[2] && fn) {
            const lets = definition[2](fn(dirty));
            if (typeof $$scope.dirty === 'object') {
                const merged = [];
                const len = Math.max($$scope.dirty.length, lets.length);
                for (let i = 0; i < len; i += 1) {
                    merged[i] = $$scope.dirty[i] | lets[i];
                }
                return merged;
            }
            return $$scope.dirty | lets;
        }
        return $$scope.dirty;
    }

    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        node.parentNode.removeChild(node);
    }
    function destroy_each(iterations, detaching) {
        for (let i = 0; i < iterations.length; i += 1) {
            if (iterations[i])
                iterations[i].d(detaching);
        }
    }
    function element(name) {
        return document.createElement(name);
    }
    function text(data) {
        return document.createTextNode(data);
    }
    function space() {
        return text(' ');
    }
    function empty() {
        return text('');
    }
    function listen(node, event, handler, options) {
        node.addEventListener(event, handler, options);
        return () => node.removeEventListener(event, handler, options);
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function children(element) {
        return Array.from(element.childNodes);
    }
    function set_data(text, data) {
        data = '' + data;
        if (text.data !== data)
            text.data = data;
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }

    const dirty_components = [];
    const binding_callbacks = [];
    const render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function tick() {
        schedule_update();
        return resolved_promise;
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    function flush() {
        const seen_callbacks = new Set();
        do {
            // first, call beforeUpdate functions
            // and update components
            while (dirty_components.length) {
                const component = dirty_components.shift();
                set_current_component(component);
                update(component.$$);
            }
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    callback();
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            const dirty = $$.dirty;
            $$.dirty = [-1];
            $$.fragment && $$.fragment.p($$.ctx, dirty);
            $$.after_update.forEach(add_render_callback);
        }
    }
    const outroing = new Set();
    let outros;
    function group_outros() {
        outros = {
            r: 0,
            c: [],
            p: outros // parent group
        };
    }
    function check_outros() {
        if (!outros.r) {
            run_all(outros.c);
        }
        outros = outros.p;
    }
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }
    function transition_out(block, local, detach, callback) {
        if (block && block.o) {
            if (outroing.has(block))
                return;
            outroing.add(block);
            outros.c.push(() => {
                outroing.delete(block);
                if (callback) {
                    if (detach)
                        block.d(1);
                    callback();
                }
            });
            block.o(local);
        }
    }
    function mount_component(component, target, anchor) {
        const { fragment, on_mount, on_destroy, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        // onMount happens before the initial afterUpdate
        add_render_callback(() => {
            const new_on_destroy = on_mount.map(run).filter(is_function);
            if (on_destroy) {
                on_destroy.push(...new_on_destroy);
            }
            else {
                // Edge case - component was destroyed immediately,
                // most likely as a result of a binding initialising
                run_all(new_on_destroy);
            }
            component.$$.on_mount = [];
        });
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const prop_values = options.props || {};
        const $$ = component.$$ = {
            fragment: null,
            ctx: null,
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            before_update: [],
            after_update: [],
            context: new Map(parent_component ? parent_component.$$.context : []),
            // everything else
            callbacks: blank_object(),
            dirty
        };
        let ready = false;
        $$.ctx = instance
            ? instance(component, prop_values, (i, ret, value = ret) => {
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if ($$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(children(options.target));
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor);
            flush();
        }
        set_current_component(parent_component);
    }
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set() {
            // overridden by instance, if it has props
        }
    }

    /* src/InlineInput.svelte generated by Svelte v3.16.7 */
    const get_selectCaret_slot_changes = dirty => ({});
    const get_selectCaret_slot_context = ctx => ({});

    function get_each_context(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[14] = list[i].label;
    	child_ctx[0] = list[i].value;
    	child_ctx[27] = i;
    	return child_ctx;
    }

    // (96:0) {:else}
    function create_else_block(ctx) {
    	let span;
    	let t0;
    	let t1;
    	let current;
    	let dispose;
    	const selectCaret_slot_template = /*$$slots*/ ctx[22].selectCaret;
    	const selectCaret_slot = create_slot(selectCaret_slot_template, ctx, /*$$scope*/ ctx[21], get_selectCaret_slot_context);
    	let if_block = /*isSelect*/ ctx[13] && create_if_block_4();

    	return {
    		c() {
    			span = element("span");
    			t0 = text(/*label*/ ctx[14]);
    			t1 = space();

    			if (!selectCaret_slot) {
    				if (if_block) if_block.c();
    			}

    			if (selectCaret_slot) selectCaret_slot.c();
    			attr(span, "class", /*labelClasses*/ ctx[3]);
    			dispose = listen(span, "click", /*toggle*/ ctx[15]);
    		},
    		m(target, anchor) {
    			insert(target, span, anchor);
    			append(span, t0);
    			append(span, t1);

    			if (!selectCaret_slot) {
    				if (if_block) if_block.m(span, null);
    			}

    			if (selectCaret_slot) {
    				selectCaret_slot.m(span, null);
    			}

    			current = true;
    		},
    		p(ctx, dirty) {
    			if (!current || dirty & /*label*/ 16384) set_data(t0, /*label*/ ctx[14]);

    			if (!selectCaret_slot) {
    				if (/*isSelect*/ ctx[13]) {
    					if (!if_block) {
    						if_block = create_if_block_4();
    						if_block.c();
    						if_block.m(span, null);
    					}
    				} else if (if_block) {
    					if_block.d(1);
    					if_block = null;
    				}
    			}

    			if (selectCaret_slot && selectCaret_slot.p && dirty & /*$$scope*/ 2097152) {
    				selectCaret_slot.p(get_slot_context(selectCaret_slot_template, ctx, /*$$scope*/ ctx[21], get_selectCaret_slot_context), get_slot_changes(selectCaret_slot_template, /*$$scope*/ ctx[21], dirty, get_selectCaret_slot_changes));
    			}

    			if (!current || dirty & /*labelClasses*/ 8) {
    				attr(span, "class", /*labelClasses*/ ctx[3]);
    			}
    		},
    		i(local) {
    			if (current) return;
    			transition_in(selectCaret_slot, local);
    			current = true;
    		},
    		o(local) {
    			transition_out(selectCaret_slot, local);
    			current = false;
    		},
    		d(detaching) {
    			if (detaching) detach(span);

    			if (!selectCaret_slot) {
    				if (if_block) if_block.d();
    			}

    			if (selectCaret_slot) selectCaret_slot.d(detaching);
    			dispose();
    		}
    	};
    }

    // (79:30) 
    function create_if_block_2(ctx) {
    	let select;
    	let if_block_anchor;
    	let select_value_value;
    	let dispose;
    	let if_block = /*placeholder*/ ctx[2] && create_if_block_3(ctx);
    	let each_value = /*options*/ ctx[7];
    	let each_blocks = [];

    	for (let i = 0; i < each_value.length; i += 1) {
    		each_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));
    	}

    	return {
    		c() {
    			select = element("select");
    			if (if_block) if_block.c();
    			if_block_anchor = empty();

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			attr(select, "class", /*inputClasses*/ ctx[4]);
    			dispose = listen(select, "blur", /*handleBlur*/ ctx[18]);
    		},
    		m(target, anchor) {
    			insert(target, select, anchor);
    			if (if_block) if_block.m(select, null);
    			append(select, if_block_anchor);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(select, null);
    			}

    			select_value_value = /*value*/ ctx[0];

    			for (var i = 0; i < select.options.length; i += 1) {
    				var option = select.options[i];

    				if (option.__value === select_value_value) {
    					option.selected = true;
    					break;
    				}
    			}

    			/*select_binding*/ ctx[25](select);
    		},
    		p(ctx, dirty) {
    			if (/*placeholder*/ ctx[2]) {
    				if (if_block) {
    					if_block.p(ctx, dirty);
    				} else {
    					if_block = create_if_block_3(ctx);
    					if_block.c();
    					if_block.m(select, if_block_anchor);
    				}
    			} else if (if_block) {
    				if_block.d(1);
    				if_block = null;
    			}

    			if (dirty & /*options*/ 128) {
    				each_value = /*options*/ ctx[7];
    				let i;

    				for (i = 0; i < each_value.length; i += 1) {
    					const child_ctx = get_each_context(ctx, each_value, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    					} else {
    						each_blocks[i] = create_each_block(child_ctx);
    						each_blocks[i].c();
    						each_blocks[i].m(select, null);
    					}
    				}

    				for (; i < each_blocks.length; i += 1) {
    					each_blocks[i].d(1);
    				}

    				each_blocks.length = each_value.length;
    			}

    			if (dirty & /*inputClasses*/ 16) {
    				attr(select, "class", /*inputClasses*/ ctx[4]);
    			}

    			if (dirty & /*value*/ 1 && select_value_value !== (select_value_value = /*value*/ ctx[0])) {
    				for (var i = 0; i < select.options.length; i += 1) {
    					var option = select.options[i];

    					if (option.__value === select_value_value) {
    						option.selected = true;
    						break;
    					}
    				}
    			}
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(select);
    			if (if_block) if_block.d();
    			destroy_each(each_blocks, detaching);
    			/*select_binding*/ ctx[25](null);
    			dispose();
    		}
    	};
    }

    // (69:32) 
    function create_if_block_1(ctx) {
    	let textarea;
    	let dispose;

    	return {
    		c() {
    			textarea = element("textarea");
    			attr(textarea, "class", /*inputClasses*/ ctx[4]);
    			attr(textarea, "placeholder", /*placeholder*/ ctx[2]);
    			textarea.value = /*value*/ ctx[0];
    			attr(textarea, "rows", /*rows*/ ctx[5]);
    			attr(textarea, "cols", /*cols*/ ctx[6]);

    			dispose = [
    				listen(textarea, "input", /*handleInput*/ ctx[16]),
    				listen(textarea, "blur", /*handleBlur*/ ctx[18])
    			];
    		},
    		m(target, anchor) {
    			insert(target, textarea, anchor);
    			/*textarea_binding*/ ctx[24](textarea);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*inputClasses*/ 16) {
    				attr(textarea, "class", /*inputClasses*/ ctx[4]);
    			}

    			if (dirty & /*placeholder*/ 4) {
    				attr(textarea, "placeholder", /*placeholder*/ ctx[2]);
    			}

    			if (dirty & /*value*/ 1) {
    				textarea.value = /*value*/ ctx[0];
    			}

    			if (dirty & /*rows*/ 32) {
    				attr(textarea, "rows", /*rows*/ ctx[5]);
    			}

    			if (dirty & /*cols*/ 64) {
    				attr(textarea, "cols", /*cols*/ ctx[6]);
    			}
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(textarea);
    			/*textarea_binding*/ ctx[24](null);
    			run_all(dispose);
    		}
    	};
    }

    // (59:0) {#if editing && (isText || isNumber)}
    function create_if_block(ctx) {
    	let input;
    	let dispose;

    	return {
    		c() {
    			input = element("input");
    			attr(input, "class", /*inputClasses*/ ctx[4]);
    			attr(input, "type", /*type*/ ctx[1]);
    			input.value = /*value*/ ctx[0];
    			attr(input, "placeholder", /*placeholder*/ ctx[2]);

    			dispose = [
    				listen(input, "input", /*handleInput*/ ctx[16]),
    				listen(input, "keyup", /*handleEnter*/ ctx[17]),
    				listen(input, "blur", /*handleBlur*/ ctx[18])
    			];
    		},
    		m(target, anchor) {
    			insert(target, input, anchor);
    			/*input_binding*/ ctx[23](input);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*inputClasses*/ 16) {
    				attr(input, "class", /*inputClasses*/ ctx[4]);
    			}

    			if (dirty & /*type*/ 2) {
    				attr(input, "type", /*type*/ ctx[1]);
    			}

    			if (dirty & /*value*/ 1) {
    				input.value = /*value*/ ctx[0];
    			}

    			if (dirty & /*placeholder*/ 4) {
    				attr(input, "placeholder", /*placeholder*/ ctx[2]);
    			}
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(input);
    			/*input_binding*/ ctx[23](null);
    			run_all(dispose);
    		}
    	};
    }

    // (102:6) {#if isSelect}
    function create_if_block_4(ctx) {
    	let span;

    	return {
    		c() {
    			span = element("span");
    			span.textContent = "▼";
    		},
    		m(target, anchor) {
    			insert(target, span, anchor);
    		},
    		d(detaching) {
    			if (detaching) detach(span);
    		}
    	};
    }

    // (85:4) {#if placeholder}
    function create_if_block_3(ctx) {
    	let option;
    	let t;

    	return {
    		c() {
    			option = element("option");
    			t = text(/*placeholder*/ ctx[2]);
    			option.selected = true;
    			option.__value = "";
    			option.value = option.__value;
    			option.disabled = true;
    		},
    		m(target, anchor) {
    			insert(target, option, anchor);
    			append(option, t);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*placeholder*/ 4) set_data(t, /*placeholder*/ ctx[2]);
    		},
    		d(detaching) {
    			if (detaching) detach(option);
    		}
    	};
    }

    // (88:4) {#each options as { label, value }
    function create_each_block(ctx) {
    	let option;
    	let t0_value = /*label*/ ctx[14] + "";
    	let t0;
    	let t1;
    	let option_key_value;
    	let option_value_value;

    	return {
    		c() {
    			option = element("option");
    			t0 = text(t0_value);
    			t1 = space();
    			attr(option, "key", option_key_value = /*i*/ ctx[27]);
    			option.__value = option_value_value = /*value*/ ctx[0];
    			option.value = option.__value;
    		},
    		m(target, anchor) {
    			insert(target, option, anchor);
    			append(option, t0);
    			append(option, t1);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*options*/ 128 && t0_value !== (t0_value = /*label*/ ctx[14] + "")) set_data(t0, t0_value);

    			if (dirty & /*options*/ 128 && option_value_value !== (option_value_value = /*value*/ ctx[0])) {
    				option.__value = option_value_value;
    			}

    			option.value = option.__value;
    		},
    		d(detaching) {
    			if (detaching) detach(option);
    		}
    	};
    }

    function create_fragment(ctx) {
    	let current_block_type_index;
    	let if_block;
    	let if_block_anchor;
    	let current;
    	const if_block_creators = [create_if_block, create_if_block_1, create_if_block_2, create_else_block];
    	const if_blocks = [];

    	function select_block_type(ctx, dirty) {
    		if (/*editing*/ ctx[8] && (/*isText*/ ctx[10] || /*isNumber*/ ctx[11])) return 0;
    		if (/*editing*/ ctx[8] && /*isTextArea*/ ctx[12]) return 1;
    		if (/*editing*/ ctx[8] && /*isSelect*/ ctx[13]) return 2;
    		return 3;
    	}

    	current_block_type_index = select_block_type(ctx);
    	if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);

    	return {
    		c() {
    			if_block.c();
    			if_block_anchor = empty();
    		},
    		m(target, anchor) {
    			if_blocks[current_block_type_index].m(target, anchor);
    			insert(target, if_block_anchor, anchor);
    			current = true;
    		},
    		p(ctx, [dirty]) {
    			let previous_block_index = current_block_type_index;
    			current_block_type_index = select_block_type(ctx);

    			if (current_block_type_index === previous_block_index) {
    				if_blocks[current_block_type_index].p(ctx, dirty);
    			} else {
    				group_outros();

    				transition_out(if_blocks[previous_block_index], 1, 1, () => {
    					if_blocks[previous_block_index] = null;
    				});

    				check_outros();
    				if_block = if_blocks[current_block_type_index];

    				if (!if_block) {
    					if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
    					if_block.c();
    				}

    				transition_in(if_block, 1);
    				if_block.m(if_block_anchor.parentNode, if_block_anchor);
    			}
    		},
    		i(local) {
    			if (current) return;
    			transition_in(if_block);
    			current = true;
    		},
    		o(local) {
    			transition_out(if_block);
    			current = false;
    		},
    		d(detaching) {
    			if_blocks[current_block_type_index].d(detaching);
    			if (detaching) detach(if_block_anchor);
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	let { value = "" } = $$props;
    	let { type = "text" } = $$props;
    	let { placeholder = "" } = $$props;
    	let { labelClasses = "" } = $$props;
    	let { inputClasses = "" } = $$props;
    	let { rows = 2 } = $$props;
    	let { cols = 20 } = $$props;
    	let { options = [] } = $$props;
    	let editing = false;
    	let inputEl;
    	let label;
    	let selectedIndex = options.findIndex(o => o.value === value);

    	const toggle = async _ => {
    		$$invalidate(8, editing = !editing);

    		if (editing) {
    			await tick();
    			inputEl.focus();
    		}
    	};

    	const handleInput = e => {
    		$$invalidate(0, value = isNumber ? +e.target.value : e.target.value);
    	};

    	const handleEnter = e => {
    		if (e.keyCode === 13) inputEl.blur();
    	};

    	const handleBlur = _ => {
    		toggle();
    	};

    	const handleChange = e => {
    		$$invalidate(19, selectedIndex = placeholder
    		? e.target.selectedIndex - 1
    		: e.target.selectedIndex);

    		$$invalidate(0, value = options[selectedIndex].value);
    	};

    	let { $$slots = {}, $$scope } = $$props;

    	function input_binding($$value) {
    		binding_callbacks[$$value ? "unshift" : "push"](() => {
    			$$invalidate(9, inputEl = $$value);
    		});
    	}

    	function textarea_binding($$value) {
    		binding_callbacks[$$value ? "unshift" : "push"](() => {
    			$$invalidate(9, inputEl = $$value);
    		});
    	}

    	function select_binding($$value) {
    		binding_callbacks[$$value ? "unshift" : "push"](() => {
    			$$invalidate(9, inputEl = $$value);
    		});
    	}

    	$$self.$set = $$props => {
    		if ("value" in $$props) $$invalidate(0, value = $$props.value);
    		if ("type" in $$props) $$invalidate(1, type = $$props.type);
    		if ("placeholder" in $$props) $$invalidate(2, placeholder = $$props.placeholder);
    		if ("labelClasses" in $$props) $$invalidate(3, labelClasses = $$props.labelClasses);
    		if ("inputClasses" in $$props) $$invalidate(4, inputClasses = $$props.inputClasses);
    		if ("rows" in $$props) $$invalidate(5, rows = $$props.rows);
    		if ("cols" in $$props) $$invalidate(6, cols = $$props.cols);
    		if ("options" in $$props) $$invalidate(7, options = $$props.options);
    		if ("$$scope" in $$props) $$invalidate(21, $$scope = $$props.$$scope);
    	};

    	let isText;
    	let isNumber;
    	let isTextArea;
    	let isSelect;

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty & /*type*/ 2) {
    			 $$invalidate(10, isText = type === "text");
    		}

    		if ($$self.$$.dirty & /*type*/ 2) {
    			 $$invalidate(11, isNumber = type === "number");
    		}

    		if ($$self.$$.dirty & /*type*/ 2) {
    			 $$invalidate(12, isTextArea = type === "textarea");
    		}

    		if ($$self.$$.dirty & /*type*/ 2) {
    			 $$invalidate(13, isSelect = type === "select");
    		}

    		if ($$self.$$.dirty & /*isNumber, value, placeholder, isText, isTextArea, selectedIndex, options*/ 531589) {
    			 if (isNumber) {
    				$$invalidate(14, label = value === "" ? placeholder : value);
    			} else if (isText || isTextArea) {
    				$$invalidate(14, label = value ? value : placeholder);
    			} else {
    				$$invalidate(14, label = selectedIndex === -1
    				? placeholder
    				: options[selectedIndex].label);
    			}
    		}
    	};

    	return [
    		value,
    		type,
    		placeholder,
    		labelClasses,
    		inputClasses,
    		rows,
    		cols,
    		options,
    		editing,
    		inputEl,
    		isText,
    		isNumber,
    		isTextArea,
    		isSelect,
    		label,
    		toggle,
    		handleInput,
    		handleEnter,
    		handleBlur,
    		selectedIndex,
    		handleChange,
    		$$scope,
    		$$slots,
    		input_binding,
    		textarea_binding,
    		select_binding
    	];
    }

    class InlineInput extends SvelteComponent {
    	constructor(options) {
    		super();

    		init(this, options, instance, create_fragment, safe_not_equal, {
    			value: 0,
    			type: 1,
    			placeholder: 2,
    			labelClasses: 3,
    			inputClasses: 4,
    			rows: 5,
    			cols: 6,
    			options: 7
    		});
    	}
    }

    return InlineInput;

})));
